@@ -145,7 +145,12 @@ convert2df<-function(file,dbsource="wos",format="plaintext"){
     M$TC[is.na(M$TC)] <- 0
   } else {M$TC <- 0}
   
-  if (!("CR" %in% names(M))){M$CR="none"}
+  if (!("CR" %in% names(M))){
+    M$CR="none"
+  } else {
+    M$CR <- trim.leading(trimES(gsub("\\[,||\\[||\\]|| \\.\\. || \\. ","",M$CR)))  # remove foreign characters from CR (i.e. Chinese, Russian characters)
+  }
+  
   if (dbsource!="cochrane"){M$AU=gsub(intToUtf8(8217),intToUtf8(39),M$AU)}
   
   cat("Done!\n\n")
