@@ -15,7 +15,7 @@
 #'
 #' @examples
 #' 
-#' #data(scientometrics)
+#' #data(scientometrics, package = "bibliometrixData")
 #' 
 #' #threeFieldsPlot(scientometrics, fields=c("DE","AU","CR"),n=c(20,20,20))
 #'
@@ -45,22 +45,25 @@ threeFieldsPlot <- function(M, fields=c("AU","DE","SO"),n=c(20,20,20), width=120
   if (length(ind)>0) Binary[ind]=TRUE
   
   ### Document x Attribute matrix Field LEFT
-  WL=cocMatrix(M,fields[1], binary=Binary[1])
+  WL=cocMatrix(M,fields[1], binary=Binary[1], n=n[1])
   n1=min(n[1],ncol(WL))
-  TopL=names(sort(Matrix::colSums(WL),decreasing = TRUE))[1:n1]
-  WL=WL[,TopL]
+  #TopL=names(sort(Matrix::colSums(WL),decreasing = TRUE))[1:n1]
+  TopL <- colnames(WL)
+  #WL=WL[,TopL]
   
   ### Document x Attribute matrix Field MIDDLE
-  WM=cocMatrix(M,fields[2], binary=Binary[2])
+  WM=cocMatrix(M,fields[2], binary=Binary[2],n=n[2])
   n2=min(n[2],ncol(WM))
-  TopM=names(sort(Matrix::colSums(WM),decreasing = TRUE))[1:n2]
-  WM=WM[,TopM]
+  #TopM=names(sort(Matrix::colSums(WM),decreasing = TRUE))[1:n2]
+  TopM <- colnames(WM)
+  #WM=WM[,TopM]
   
   ### Document x Attribute matrix Field RIGHT
-  WR=cocMatrix(M,fields[3], binary=Binary[3])
+  WR=cocMatrix(M,fields[3], binary=Binary[3],n=n[3])
   n3=min(n[3],ncol(WR))
-  TopR=names(sort(Matrix::colSums(WR),decreasing = TRUE))[1:n3]
-  WR=WR[,TopR]
+  #TopR=names(sort(Matrix::colSums(WR),decreasing = TRUE))[1:n3]
+  TopR <- colnames(WR)
+  #WR=WR[,TopR]
   
   ### Co-Occurrence Matrices
   LM=Matrix::crossprod(WL,WM)
@@ -102,7 +105,7 @@ threeFieldsPlot <- function(M, fields=c("AU","DE","SO"),n=c(20,20,20), width=120
 
 ## function to melt data
 meltx <- function(LM) {
-  var1 <- rep((1:nrow(LM)), nrow(LM))
+  var1 <- rep((1:nrow(LM)), ncol(LM))
   var2 <- sort(var1)
   LMM <-
     data.frame(
