@@ -1,19 +1,20 @@
 #' @import stats
 #' @import dimensionsR
 #' @import ggplot2
-# @import RISmed
+#' @import bibliometrixData
 #' @import ggrepel
 #' @import ggraph
 #' @import pubmedR
 #' @import shiny
-#' @import shinycssloaders
-#' @import shinythemes
+# #' @import shinycssloaders
+# #' @import shinythemes
 #' @importFrom tidyr gather
 #' @importFrom tidyr spread
 #' @importFrom tidyr pivot_wider
 #' @importFrom tidyr pivot_longer
 #' @importFrom grDevices adjustcolor
 #' @importFrom dplyr %>%
+#' @importFrom dplyr tibble
 # @importFrom dplyr filter
 #' @importFrom dplyr arrange
 #' @importFrom dplyr desc
@@ -222,14 +223,17 @@
 #' @importFrom graphics lines
 #' @importFrom graphics plot
 #' @importFrom graphics par
+#' @importFrom utils capture.output
 #' @importFrom utils data
 #' @importFrom utils adist
+#' @importFrom utils read.csv
 #' @importFrom SnowballC wordStem
 #' @importFrom SnowballC getStemLanguages
 #' @importFrom rio import
 .onAttach<-function(...){
   packageStartupMessage("To cite bibliometrix in publications, please use:\n\nAria, M. & Cuccurullo, C. (2017) bibliometrix: An R-tool for comprehensive science mapping analysis, Journal of Informetrics, 11(4), pp 959-975, Elsevier.
                         \n\nhttp:\\\\www.bibliometrix.org\n
+                        \nHelp us to keep Bibliometrix free to download and use by contributing with a small donation to support our research team (https://bibliometrix.org/donate.html)\n
                         \nTo start with the shiny web-interface, please digit:
 biblioshiny()\n")
 }
